# Installation

The library requires Python 3.8+ and can be installed using PIP:

!!! note

    Please mind that the library on PyPi is `dplib-py` not `dplib`

```bash
pip install dplib-py
```

The library comes with plugins that can require additional extra dependencies. Please consult with [plugins documentation](plugins/ckan.md)
